docs.rs failed to build jetstreamer-utils-0.1.2
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
jetstreamer-utils-0.5.1
Shared utilities for Jetstreamer components.
Currently this crate provides helpers for spawning local ClickHouse instances that were previously part of the deprecated Geyser plugin crate.