pub type ClickhouseStartResult = (Receiver<()>, ClickhouseProcessFuture);Expand description
Tuple containing the readiness channel and process future returned by start.
pub type ClickhouseStartResult = (Receiver<()>, ClickhouseProcessFuture);Tuple containing the readiness channel and process future returned by start.